Reland "[autotest]: Update tests to use new container IP"

This reverts commit 93f5591d1d8adff2d13d215ce049934265ef6529.

CQ-DEPEND=CL:*316346
CQ-DEPEND=CL:424950
BUG=b:31285667

Change-Id: I2250b0a6fc534cdc0c6456a75b474c1cf12687fa
Reviewed-on: https://chromium-review.googlesource.com/480922
Commit-Ready: Abhishek Bhardwaj <abhishekbh@google.com>
Tested-by: Ilja H. Friedel <ihf@chromium.org>
Tested-by: Abhishek Bhardwaj <abhishekbh@google.com>
Reviewed-by: Abhishek Bhardwaj <abhishekbh@google.com>
diff --git a/client/common_lib/cros/arc.py b/client/common_lib/cros/arc.py
index c955cdc..1fb2f0f 100644
--- a/client/common_lib/cros/arc.py
+++ b/client/common_lib/cros/arc.py
@@ -612,15 +612,14 @@
     def block_outbound(self):
         """ Blocks the connection from the container to outer network.
 
             The iptables settings accept only 192.168.254.2 port 5555 (adb) and
             all local connections, e.g. uiautomator.
         """
         logging.info('Blocking outbound connection')
         _android_shell('iptables -I OUTPUT -j REJECT')
-        _android_shell('iptables -I OUTPUT -p tcp -s 192.168.254.2 --sport 5555 -j ACCEPT')
+        _android_shell('iptables -I OUTPUT -p tcp -s 100.115.92.2 --sport 5555 -j ACCEPT')
         _android_shell('iptables -I OUTPUT -p tcp -d localhost -j ACCEPT')
 
-
     def unblock_outbound(self):
         """ Unblocks the connection from the container to outer network.
 
@@ -630,5 +629,4 @@
         """
         logging.info('Unblocking outbound connection')
         _android_shell('iptables -D OUTPUT -p tcp -d localhost -j ACCEPT')
-        _android_shell('iptables -D OUTPUT -p tcp -s 192.168.254.2 --sport 5555 -j ACCEPT')
-        _android_shell('iptables -D OUTPUT -j REJECT')
+        _android_shell('iptables -D OUTPUT -p tcp -s 100.115.92.2 --sport 5555 -j ACCEPT')
@@ -612,15 +612,14 @@
         """ Blocks the connection from the container to outer network.
 
-            The iptables settings accept only 192.168.254.2 port 5555 (adb) and
+            The iptables settings accept only 100.115.92.2 port 5555 (adb) and
             all local connections, e.g. uiautomator.
         """